@@ -1,24 +1,26 @@
 /*
-@licstart  The following is the entire license notice for the
-JavaScript code in this file.
+ @licstart  The following is the entire license notice for the JavaScript code in this file.
 
-Copyright (C) 1997-2019 by Dimitri van Heesch
+ The MIT License (MIT)
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of version 2 of the GNU General Public License as published by
-the Free Software Foundation
+ Copyright (C) 1997-2020 by Dimitri van Heesch
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-GNU General Public License for more details.
+ Permission is hereby granted, free of charge, to any person obtaining a copy of this software
+ and associated documentation files (the "Software"), to deal in the Software without restriction,
+ including without limitation the rights to use, copy, modify, merge, publish, distribute,
+ sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
+ furnished to do so, subject to the following conditions:
 
-You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ The above copyright notice and this permission notice shall be included in all copies or
+ substantial portions of the Software.
 
-@licend  The above is the entire license notice
-for the JavaScript code in this file
+ THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
+ BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
+ NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
+ DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
+ @licend  The above is the entire license notice for the JavaScript code in this file
 */
 var NAVTREE =
 [
@@ -100,13 +102,13 @@ var NAVTREEINDEX =
 [
 "annotated.html",
 "core_8h.html#a4c5b5cb41d6256b5262ca232f03ee6ef",
-"global_8h.html#ac8b5326a91752657ed445c5d87010684",
-"impl-node_8c.html#a9d1dd8ccb022c97ae13215d735cc5ab3",
-"link_8h.html#aa90bcda1ac9edbb5f2c92703f1e38d84",
+"global_8h.html#ab6796dae933803798be1658f4020315c",
+"impl-node_8c.html#a9a92f81d55af5f321ec522182fd9ef7c",
+"link_8h.html#aa09465885f2b5edd3aecf62a2e8f7ef7",
 "pipewire_8c.html#ad6b599f28dfb2e60a14ac4cf01d4c18c",
 "stream_8h_source.html",
-"structpw__impl__client__events.html#a046e956441b5395308c8ff140292dfee",
-"structpw__registry__events.html#a3fa28cf2cd3ed8739debec5bb17ace61"
+"structpw__impl__client__events.html",
+"structpw__registry__events.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
